@@ -2,7 +2,7 @@
 
 /*
     UTStatsDB
-    Copyright (C) 2002-2007  Patrick Contreras / Paul Gallier
+    Copyright (C) 2002-2008  Patrick Contreras / Paul Gallier
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -485,7 +485,7 @@ echo <<<EOF
 EOF;
 
 $matches = 0;
-$result = sql_queryn($link, "SELECT gm_num,gm_server,gm_type,gm_start,gm_length,gm_numplayers,sv_name
+$result = sql_queryn($link, "SELECT gm_num,gm_server,gm_type,gm_start,gm_length,gm_numplayers,sv_name,sv_shortname
                        FROM {$dbpre}matches,{$dbpre}servers
                        WHERE gm_map=$mapnum AND {$dbpre}servers.sv_num=gm_server
                        ORDER BY gm_num DESC LIMIT 21");
@@ -506,7 +506,10 @@ while ($row = sql_fetch_assoc($result)) {
     $start = strtotime($gm_start);
     $matchdate = formatdate($start, 1);
     $length = sprintf("%0.1f", $gm_length / 6000.0);
-    $servername = stripspecialchars($sv_name);
+    if ($useshortname)
+      $servername = stripspecialchars($sv_shortname);
+    else
+      $servername = stripspecialchars($sv_name);
 
     echo <<<EOF
   <tr>
