@@ -2,7 +2,7 @@
 
 /*
     UTStatsDB
-    Copyright (C) 2002-2007  Patrick Contreras / Paul Gallier
+    Copyright (C) 2002-2008  Patrick Contreras / Paul Gallier
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -102,14 +102,17 @@ else {
 sql_free_result($result);
 
 // Load Server Data
-$result = sql_queryn($link, "SELECT sv_name,sv_admin,sv_email FROM {$dbpre}servers WHERE sv_num=$gm_server LIMIT 1");
+$result = sql_queryn($link, "SELECT sv_name,sv_shortname,sv_admin,sv_email FROM {$dbpre}servers WHERE sv_num=$gm_server LIMIT 1");
 if (!$result) {
   echo "Server database error.<br />\n";
   exit;
 }
-list($sv_name,$sv_admin,$sv_email) = sql_fetch_row($result);
+list($sv_name,$sv_shortname,$sv_admin,$sv_email) = sql_fetch_row($result);
 sql_free_result($result);
-$servername = stripspecialchars($sv_name);
+if ($useshortname)
+  $servername = stripspecialchars($sv_shortname);
+else
+  $servername = stripspecialchars($sv_name);
 $serveradmin = stripspecialchars($sv_admin);
 $serveremail = stripspecialchars($sv_email);
 
@@ -1367,37 +1370,45 @@ echo <<<EOF
 
 EOF;
 
+// Load Item Descriptions
 $result = sql_queryn($link, "SELECT it_num,it_desc FROM {$dbpre}items");
 if (!$result) {
-  echo "Error loading item pickup descriptions.<br />\n";
+  echo "{$LANG_ERRORLOADINGITEMPICKUPDESC}<br />\n";
   exit;
 }
-$numitems = 0;
-while ($row = sql_fetch_row($result)) {
-  $num = intval($row[0]);
-  $pickups[0][$num] = $row[1];
-  $pickups[1][$num] = 0;
-  $numitems++;
-}
+$items = array();
+while ($row = sql_fetch_row($result))
+  $items[$row[0]] = $row[1];
 sql_free_result($result);
 
 $result = sql_queryn($link, "SELECT gi_item,gi_pickups FROM {$dbpre}gitems WHERE gi_match=$matchnum AND gi_plr=$gp_num");
 if (!$result) {
-  echo "Error loading item pickups.<br />\n";
+  echo "{$LANG_ERRORLOADINGITEMPICKUPS}<br />\n";
   exit;
 }
+
+$pickups = array(array());
+$totpickups = 0;
 while ($row = sql_fetch_row($result)) {
-  $num = intval($row[0]);
-  $pickups[1][$num] += $row[1];
+  for ($i = 0, $item = -1; $i < $totpickups && $item < 0; $i++) {
+    if (!strcmp($pickups[0][$i], $items[$row[0]]))
+      $item = $i;
+  }
+  if ($item < 0) {
+    $pickups[0][$totpickups] = $items[$row[0]];
+    $pickups[1][$totpickups++] = $row[1];
+  }
+  else
+    $pickups[1][$item] += $row[1];
 }
 sql_free_result($result);
 
-if ($numitems > 0)
+if ($totpickups > 0)
   array_multisort($pickups[1], SORT_DESC, SORT_NUMERIC,
                   $pickups[0], SORT_ASC, SORT_STRING);
 
-$col = $totpickups = 0;
-for ($i = 0; $i < $numitems; $i++) {
+$col = 0;
+for ($i = 0; $i < $totpickups; $i++) {
   $item = $pickups[0][$i];
   $num = $pickups[1][$i];
   if ($num) {
@@ -1413,7 +1424,6 @@ EOF;
     if ($col == 2)
       echo "  </tr>\n";
     $col++;
-    $totpickups++;
   }
 }
 
