@@ -1,7 +1,7 @@
 CREATE TABLE %dbpre%weapons (
   wp_num smallint(5) unsigned NOT NULL auto_increment,
-  wp_type varchar(35) NOT NULL default '',
-  wp_desc varchar(35) NOT NULL default '',
+  wp_type varchar(60) NOT NULL default '',
+  wp_desc varchar(40) NOT NULL default '',
   wp_weaptype tinyint(3) unsigned NOT NULL default 0,
   wp_secondary tinyint(3) unsigned NOT NULL default 0,
   wp_frags int(11) NOT NULL default 0,
@@ -49,7 +49,7 @@ CREATE TABLE %dbpre%weapons (
   wp_chsuicidessg_map mediumint(8) unsigned NOT NULL default 0,
   wp_chsuicidessg_dt datetime NOT NULL default '0000-00-00 00:00:00',
   UNIQUE KEY wp_num (wp_num),
-  KEY wp_type (wp_type),
+  UNIQUE KEY wp_type (wp_type),
   KEY wp_weaptype (wp_weaptype)
 ) Type=MyISAM;
 
@@ -259,8 +259,8 @@ INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('Da
 #
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('DamTypeAtakapa50Cal','Atakapa',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('DamTypeAtakapaMissle','Atakapa',1,1);
-INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('DamTypeAttackCraftRoadkill','Atakapa',1,4);
-INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('DamTypeAttackCraftPancake','Atakapa',1,4);
+#INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('DamTypeAttackCraftRoadkill','Atakapa',1,4);
+#INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('DamTypeAttackCraftPancake','Atakapa',1,4);
 #
 #
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('ASTurret','Turret',1);
@@ -522,6 +522,7 @@ INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_SniperPrimary','S
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES('UTDmgType_SniperHeadShot','Sniper Rifle',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_Redeemer','Redeemer');
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Redeemer','Redeemer');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_Redeemer_Content','Redeemer');
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Telefrag','Telefrag');
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_Translocator','Translocator');
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_FailedTranslocation','Translocator');
@@ -541,16 +542,20 @@ INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Slime','Slimed');
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Lava','Fell Into Lava');
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('DmgType_Fell','Fell');
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Fire','Fire');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('DmgType_Crushed','Crushed');
 #--------------------------------------------------------------------------------------------------
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_ScorpionTurret','Scorpion',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScorpionBlade','Scorpion',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScorpionGlob','Scorpion',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScorpionGlobRed','Scorpion',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScorpionSelfDestruct','Scorpion',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_MantaGun','Manta',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_MantaBolt','Manta',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_HellBenderPrimary','Hell Bender',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_GoliathTurret','Goliath',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_TankShell','Goliath',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_GoliathMachineGun','Goliath Machine Gun',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_GoliathMachineGun','Goliath Machine Gun',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_LeviathanBeam','Leviathan',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_LeviathanBolt','Leviathan',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_LeviathanCollision','Leviathan',1,1);
@@ -564,13 +569,16 @@ INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_Palad
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_RaptorGun','Raptor',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_RaptorBolt','Raptor',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_RaptorRocket','Raptor',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_CicadaMissileLauncher','Cicada',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_CicadaLaser','Cicada',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_CicadaRocket','Cicada',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_FuryBeam','Fury',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_FuryBolt','Fury',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_ScavengerGun','Scavenger',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScavengerBolt','Scavenger',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScavengerStabbed','Scavenger',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScavengerBallCollision','Scavenger',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_DarkWalkerPassGun','Dark Walker',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_DarkWalkerBolt','Dark Walker',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_DarkWalkerTurretBeam','Dark Walker',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_DarkWalkerTurret','Dark Walker',1);
@@ -584,6 +592,7 @@ INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_SPMAS
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_SPMAShockChain','SPMA',1,1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_SPMASmallShell','SPMA',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_SPMACameraCrush','SPMA',1,1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_ViperGun','Viper',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ViperBolt','Viper',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_ViperSelfDestruct','Viper',1,1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_Pancake','Pancaked',1,4);
@@ -593,10 +602,13 @@ INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_Vehic
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_VehicleShockBall','Vehicle Shock Turret',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_VehicleShockBeam','Vehicle Shock Turret',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_VehicleShockChain','Vehicle Shock Turret',1,1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_TurretPrimary','Laser Turret',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_TurretPrimary','Laser Turret',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_RocketTurret','Rocket Turret',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_TurretRocket','Rocket Turret',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_TurretStinger','Machine Gun Turret',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_TurretShard','Machine Gun Turret',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_TurretShock','Shock Turret',1);
 INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_TurretShockBall','Shock Turret',1);
 #--------------------------------------------------------------------------------------------------
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_NodeDestruction','Node Destruction');
@@ -604,5 +616,25 @@ INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_EMP','EMP');
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Encroached','Encroached');
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_OrbReturn','Orb Return');
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_SpaceDeath','Space Death');
+#--------------------------------------------------------------------------------------------------
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_RipperLite','Ripper');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_RipperLite','Ripper');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_RipperLiteHeadshot','Ripper');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES('UTDmgType_RipperLiteAlt','Ripper',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('KillZDamageType','Fell');
+#--------------------------------------------------------------------------------------------------
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleWeapon_ImpactHammer','Impact Hammer');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleWeapon_Enforcer','Enforcer');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleWeapon_BioRifle','Bio Rifle');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleWeapon_ShockRifle','Shock Rifle');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleWeapon_LinkGun','Link Gun');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleWeapon_Stinger','Stinger Minigun');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleWeapon_FlakCannon','Flak Cannon');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleWeapon_RocketLauncher','Rocket Launcher');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleWeapon_SniperRifle','Sniper Rifle');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleDamageType_LateEntry','Late Entry');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleDamageType_ReverseFriendlyFire','Reverse Fire');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleDamageType_RoundOvertime','Round Overtime');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('BattleDamageType_Camping','Camping');
 #
 #INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('','');
